@@ -153,7 +153,7 @@ setMethodS3("getAlleleProbePairs3", "AffymetrixCdfFile", function(this, units=NU
     verbose && str(verbose, unitsChunk);
 
     verbose && enter(verbose, "Reading group names, group directions, and cell indices");
-    cdfData <- readCdf(pathname, units=unitsChunk, readIndices=TRUE, readXY=FALSE, readAtoms=FALSE, readIndexpos=FALSE, readBases=FALSE, readUnitNumber=FALSE, readUnitType=FALSE, readUnitDir=FALSE, readGroupAtomNumbers=FALSE, stratifyBy="pm");
+    cdfData <- readCdf(pathname, units=unitsChunk, readIndices=TRUE, readXY=FALSE, readAtoms=FALSE, readIndexpos=FALSE, readBases=FALSE, readUnitNumber=FALSE, readUnitType=FALSE, readUnitDirection=FALSE, readGroupAtomNumbers=FALSE, stratifyBy="pm");
     verbose && exit(verbose);
 
     # Save memory by removing names. [55Mb -> 44Mb]
@@ -331,6 +331,9 @@ setMethodS3("getAlleleProbePairs3", "AffymetrixCdfFile", function(this, units=NU
 
 ############################################################################
 # HISTORY:
+# 2011-02-01
+# o ROBUSTNESS: Now using argument 'readUnitDirection' (not 'readUnitDir')
+#   in calls to readCdf().
 # 2008-09-02
 # o CONFIRMED: For GWS6, getAlleleProbePairs3() returns the same vector of
 #   'nonSNPs' cell indices as getAlleleProbePairs().  They also returns the
