@@ -18,17 +18,17 @@ sampleNames <- c("NA06985", "NA06991", "NA06993",
 cdf <- AffymetrixCdfFile$byChipType(chipType, tags="Full,r2");
 print(cdf);
 
-cs <- AffymetrixCelSet$byName(dataSetName, cdf=cdf, verbose=log);
-print(cs);
-stopifnot(identical(getNames(cs), sampleNames));
+csR <- AffymetrixCelSet$byName(dataSetName, cdf=cdf, verbose=log);
+print(csR);
+stopifnot(identical(getNames(csR), sampleNames));
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Allelic-crosstalk calibration
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-acc <- AllelicCrosstalkCalibration(cs);
+acc <- AllelicCrosstalkCalibration(csR);
 print(acc);
 
 csC <- process(acc, verbose=log);
 print(csC);
-stopifnot(identical(getNames(csC), getNames(cs)));
+stopifnot(identical(getNames(csC), getNames(csR)));
